@@ -3,6 +3,7 @@ import re
 from zipfile import ZipFile
 import shutil
 import pkgutil
+import json
 
 
 def appendContent(path, content, find=None, recursive=False):
@@ -732,4 +733,241 @@ def modifyFilesNewAPI(version,group,name,http_verb,type_api,url,availability,pro
         if error[1] == True:
             return error[0], False
 
+    return "OK", True
+
+def modifyFilesNewGraph(version,group,name,type_graph,project_name):
+    """
+        Función encargada de modificar archivos para nuevo graph en django
+
+        Función encargada de modificar los archivos necesarios para crear un nuev graph
+        en el proyecto django.
+
+        Parámetros:
+            version         [String]    Versión donde se creará el Graph
+            group           [String]    Grupo donde se creará el Graph
+            name            [String]    Nombre del Graph
+            type_graph      [String]    Tipo del Graph (MODEL, OPEN)
+            project_name    [String]    Nombre del proyecto
+        Retorno:
+            message,result  [Tuple]     Mensaje[String] y result[Boolean]
+    """
+    errors = []
+    primary_package = "springlabs_django"
+    
+
+    graph_version = version
+    group_graph = group
+    name_graph = name
+    try:
+        with open('springlabs_django.json') as file:
+            data = json.load(file)
+    except:
+        message = "Ocurrió un problema interno al leer archivo (springlabs_django.json)"
+        return message, False
+    else:
+        versions_detail = data['versions_detail']
+        old_graphs = []
+        names_no_valid = []
+        # Recorremos todas las versiones
+        for versions in versions_detail:
+            # Si la versión del ciclo es en donde vamos a insertar el graph
+            if versions['version'] == graph_version:
+                groups_detail = versions["groups_detail"]
+                # Recorremos todos los grupos de esa versión
+                for group_detail in groups_detail:
+                    # Si el grupo del ciclo es en donde vamos a insertar el graph
+                    if group_graph == group_detail['group']:
+                        graphs = group_detail['graph']
+                        # Recorremos todas las apis de ese grupo
+                        for graph in graphs:
+                            old_name = graph["graph_name"]
+                            # Agregamos a lista de old_graphs los nombres de los graphs existentes
+                            old_graphs.append(old_name)
+    
+    # Si se encuentra ExampleDjango en los graphs existentes
+    if "ExampleDjango" in old_graphs:
+        delete_example = True 
+    else:
+        delete_example = False
+    # Obtener variables dependientes del TYPE_GRAPH
+    base_schema = "schema.py"
+    if type_graph=="open":
+        base_types = "types_open.py"
+    elif type_graph=="model":
+        base_types = "types_model.py"
+    
+    base_schema_py = f"/core/new_graph/graph/{base_schema}"
+    base_types_py = f"/core/new_graph/graph/{base_types}"
+
+    # Obtiene contenido de /core/new_graph/graph/{base_schema}
+    try:
+        template_schema_py = pkgutil.get_data(primary_package, base_schema_py).decode('utf-8')
+        template_schema_py = template_schema_py.replace("GRAPH_NAME", name.capitalize())
+    except:
+        message = f"Ocurrió un error interno en /core/new_graph/graph/{base_schema}"
+        errors.append([message, True])
+    
+    # Obtiene contenido de /core/new_graph/graph/{base_types}
+    try:
+        template_types_py = pkgutil.get_data(primary_package, base_types_py).decode('utf-8')
+        template_types_py = template_types_py.replace("GRAPH_NAME", name.capitalize())
+    except:
+        message = f"Ocurrió un error interno en /core/new_graph/graph/{base_types}"
+        errors.append([message, True])
+    
+    # Obtiene texto a buscar de import en schema.py y api.py
+    find_import_schema = "from .types import"
+    find_import_api = f"from .{group}.schema import"
+    find_query_api = f"class Query("
+    for index, old_graph in enumerate(old_graphs):
+        if old_graph != "ExampleDjango":
+            old_graph_name = old_graph.capitalize()
+        else:
+            old_graph_name = old_graph
+        if index == 0:
+            
+            find_import_schema = find_import_schema+f" {old_graph_name}Type"
+            find_import_api = find_import_api+f" {old_graph_name}Queries"
+            find_query_api = find_query_api+f"{old_graph_name}Queries"
+        else:
+            find_import_schema = find_import_schema+f", {old_graph_name}Type"
+            find_import_api = find_import_api+f", {old_graph_name}Queries"
+            find_query_api = find_query_api+f", {old_graph_name}Queries"
+    base_new_query_api = str(find_query_api)
+    find_query_api = find_query_api + ", graphene.ObjectType):"
+    # Elimina ExampleDjango de archivo schema.py y types.py
+    if delete_example==True:
+        # Elimina ExampleDjango de archivo schema.py
+        path = f"graphql_api/v{version}/{group}/schema.py"
+        message, result = deleteContent(path=path,
+            start="# EXAMPLE QUERY GRAPHENE (Managed by SPRINGLABS_DJANGO)",
+            end="# END EXAMPLE QUERY GRAPHENE (Managed by SPRINGLABS_DJANGO)")
+        if result == False:
+            errors.append([message, True])
+        
+        message, result = findNDelete(path=path,
+            find="# EXAMPLE QUERY GRAPHENE (Managed by SPRINGLABS_DJANGO)")
+        if result == False:
+            errors.append([message, True])
+        
+        message, result = findNDelete(path=path,
+            find="# END EXAMPLE QUERY GRAPHENE (Managed by SPRINGLABS_DJANGO)")
+        if result == False:
+            errors.append([message, True])
+        
+        # Elimina ExampleDjango de archivo types.py
+        path = f"graphql_api/v{version}/{group}/types.py"
+        message, result = deleteContent(path=path,
+            start="# EXAMPLE GRAPHENE ObjectType (Managed by SPRINGLABS_DJANGO)",
+            end="# END EXAMPLE GRAPHENE ObjectType (Managed by SPRINGLABS_DJANGO)")
+        if result == False:
+            errors.append([message, True])
+        
+        message, result = findNDelete(path=path,
+            find="# EXAMPLE GRAPHENE ObjectType (Managed by SPRINGLABS_DJANGO)")
+        if result == False:
+            errors.append([message, True])
+        
+        message, result = findNDelete(path=path,
+            find="# END EXAMPLE GRAPHENE ObjectType (Managed by SPRINGLABS_DJANGO)")
+        if result == False:
+            errors.append([message, True])
+        
+        new_import_schema = f"from .types import {name.capitalize()}Type"
+        new_import_api = f"from .{group}.schema import {name.capitalize()}Queries"
+        new_query_api = f"class Query({name.capitalize()}Queries"
+        for index, old_graph in enumerate(old_graphs):
+            if old_graph != "ExampleDjango":
+                if index == 0:
+                    new_import_schema = new_import_schema+f" {old_graph.capitalize()}Type"
+                    new_import_api = new_import_api+f" {old_graph.capitalize()}Queries"
+                    new_query_api = new_query_api+f" {old_graph.capitalize()}Queries"
+                else:
+                    new_import_schema = new_import_schema+f", {old_graph}Type"
+                    new_import_api = new_import_api+f", {old_graph.capitalize()}Queries"
+                    new_query_api = new_query_api+f", {old_graph.capitalize()}Queries"
+        index_graph_example_django = False
+        try:
+            with open('springlabs_django.json') as file:
+                data = json.load(file)
+        except:
+            message = "Ocurrio un error interno al actualizar archivo springlabs_django.json"
+            errors.append([message, True])
+        else:
+            objGraph = {
+                "graph_name": name,
+                "graph_type": type_graph
+            }
+            versions_detail = data['versions_detail']
+            # Recorremos todas las versiones
+            for index_versions, versions in enumerate(versions_detail):
+                # Si la versión del ciclo es en donde vamos a insertar el graph
+                if versions['version'] == version:
+                    groups_detail = versions["groups_detail"]
+                    # Recorremos todos los grupos de esa versión
+                    for index_groups, group_detail in enumerate(groups_detail):
+                        # Si el grupo del ciclo es en donde vamos a insertar el graph
+                        if group == group_detail['group']:
+                            graphs_json = group_detail['graph']
+                            # Recorremos los graphs en la aplicación y grupo especificados
+                            for index_graph, graph_json in enumerate(graphs_json):
+                                if graph_json['graph_name'] == "ExampleDjango":
+                                    index_graph_example_django = [index_versions,index_groups,index_graph]
+            # Si existió graphQL en la lista de graphs de la versión y grupo
+            if index_graph_example_django != False:
+                # Elimina el graph de Example Django
+                index_version = index_graph_example_django[0]
+                index_groups = index_graph_example_django[1]
+                index_graph = index_graph_example_django[2]
+                data['versions_detail'][index_versions]['groups_detail'][index_groups]['graph'].pop(index_graph)
+            try:
+                with open("springlabs_django.json", "w") as file:
+                    file.write(json.dumps(data))
+            except:
+                message = "Ocurrio un error interno al actualizar archivo springlabs_django.json"
+                errors.append([message, True])
+    else:
+        new_import_schema = find_import_schema + f", {name.capitalize()}Type"
+        new_import_api = find_import_api + f", {name.capitalize()}Queries"
+        new_query_api = base_new_query_api + f", {name.capitalize()}Queries"
+    new_query_api = new_query_api + ", graphene.ObjectType):"
+    # Escribe nuevo graph en archivo schema.py
+    path = f"graphql_api/v{version}/{group}/schema.py"
+    message, result = appendContent(path=path,
+        content=template_schema_py)
+    if result == False:
+        errors.append([message, True])
+    
+    # Modifica imports en schema.py
+    message, result = findNReplace(path=path,
+        content=new_import_schema,
+        find=find_import_schema)
+    if result == False:
+        errors.append([message, True])
+
+    # Escribe en archivo types.py
+    path = f"graphql_api/v{version}/{group}/types.py"
+    message, result = appendContent(path=path,
+        content=template_types_py)
+    if result == False:
+        errors.append([message, True])
+
+    # Escribe en archivo api.py
+    path = f"graphql_api/v{version}/api.py"
+    message, result = findNReplace(path=path,
+        content=new_import_api,
+        find=find_import_api)
+    if result == False:
+        errors.append([message, True])
+    
+    message, result = findNReplace(path=path,
+        content=new_query_api,
+        find=find_query_api)
+    if result == False:
+        errors.append([message, True])
+
+    for error in errors:
+        if error[1] == True:
+            return error[0], False
+
     return "OK", True
\ No newline at end of file
